Score Functions and Case-wise Derivatives
Arguments
- x
A fitted
merModobject fromlmer.- level
If
level = 1, scores at level-1 are returned; iflevel = 2, which is the default, aggregated scores at the cluster- level are returned.
Score Functions and Case-wise Derivatives
A fitted merMod object from lmer.
If level = 1, scores at level-1 are returned; if
level = 2, which is the default, aggregated scores at the cluster-
level are returned.